@@ -19,7 +19,10 @@ import glob
 import itertools
 import logging
 import os
+import queue
 import random
+import socket
+import threading
 import uuid
 
 from concurrent import futures
@@ -29,6 +32,7 @@ from keystoneauth1 import exceptions as ka_exceptions
 from oslo_config import cfg
 from oslo_log import log
 import oslo_messaging
+from oslo_utils import netutils
 from oslo_utils import timeutils
 from stevedore import extension
 from tooz import coordination
@@ -41,6 +45,7 @@ from ceilometer import keystone_client
 from ceilometer import messaging
 from ceilometer.polling import dynamic_pollster
 from ceilometer.polling import plugin_base
+from ceilometer.polling import prom_exporter
 from ceilometer.publisher import utils as publisher_utils
 from ceilometer import utils
 
@@ -51,6 +56,10 @@ POLLING_OPTS = [
                default="polling.yaml",
                help="Configuration file for polling definition."
                ),
+    cfg.StrOpt('heartbeat_socket_dir',
+               default=None,
+               help="Path to directory where socket file for polling "
+                    "heartbeat will be created."),
     cfg.StrOpt('partitioning_group_prefix',
                deprecated_group='central',
                help='Work-load partitioning group prefix. Use only if you '
@@ -61,22 +70,42 @@ POLLING_OPTS = [
     cfg.IntOpt('batch_size',
                default=50,
                help='Batch size of samples to send to notification agent, '
-                    'Set to 0 to disable'),
+                    'Set to 0 to disable. When prometheus exporter feature '
+                    'is used, this should be largered than maximum number of '
+                    'samples per metric.'),
     cfg.MultiStrOpt('pollsters_definitions_dirs',
                     default=["/etc/ceilometer/pollsters.d"],
                     help="List of directories with YAML files used "
                          "to created pollsters."),
-    cfg.BoolOpt('tenant_name_discovery',
+    cfg.BoolOpt('identity_name_discovery',
+                deprecated_name='tenant_name_discovery',
                 default=False,
                 help='Identify project and user names from polled samples. '
                      'By default, collecting these values is disabled due '
-                     'to the fact that it could overwhelm keystone service'
+                     'to the fact that it could overwhelm keystone service '
                      'with lots of continuous requests depending upon the '
                      'number of projects, users and samples polled from '
                      'the environment. While using this feature, it is '
                      'recommended that ceilometer be configured with a '
                      'caching backend to reduce the number of calls '
                      'made to keystone.'),
+    cfg.BoolOpt('enable_notifications',
+                default=True,
+                help='Whether the polling service should be sending '
+                     'notifications after polling cycles.'),
+    cfg.BoolOpt('enable_prometheus_exporter',
+                default=False,
+                help='Allow this ceilometer polling instance to '
+                     'expose directly the retrieved metrics in Prometheus '
+                     'format.'),
+    cfg.ListOpt('prometheus_listen_addresses',
+                default=["127.0.0.1:9101"],
+                help='A list of ipaddr:port combinations on which '
+                     'the exported metrics will be exposed.'),
+    cfg.BoolOpt('ignore_disabled_projects',
+                default=False,
+                help='Whether the polling service should ignore '
+                     'disabled projects or not.'),
 ]
 
 
@@ -89,6 +118,11 @@ class PollingException(agent.ConfigException):
         super(PollingException, self).__init__('Polling', message, cfg)
 
 
+class HeartBeatException(agent.ConfigException):
+    def __init__(self, message, cfg):
+        super(HeartBeatException, self).__init__('Polling', message, cfg)
+
+
 class Resources(object):
     def __init__(self, agent_manager):
         self.agent_manager = agent_manager
@@ -146,13 +180,12 @@ class PollingTask(object):
         resource_factory = lambda: Resources(agent_manager)  # noqa: E731
         self.resources = collections.defaultdict(resource_factory)
 
-        self._batch_size = self.manager.conf.polling.batch_size
-
-        self._telemetry_secret = self.manager.conf.publisher.telemetry_secret
-
+        conf = self.manager.conf
+        self._batch_size = conf.polling.batch_size
+        self._telemetry_secret = conf.publisher.telemetry_secret
         self.ks_client = self.manager.keystone
-
-        self._cache = cache_utils.get_client(self.manager.conf)
+        self._name_discovery = conf.polling.identity_name_discovery
+        self._cache = cache_utils.get_client(conf)
 
     def add(self, pollster, source):
         self.pollster_matches[source.name].add(pollster)
@@ -207,14 +240,13 @@ class PollingTask(object):
                     )
                     sample_batch = []
 
+                    self.manager.heartbeat(pollster.name, polling_timestamp)
+
                     for sample in samples:
                         # Note(yuywz): Unify the timestamp of polled samples
                         sample.set_timestamp(polling_timestamp)
 
-                        if (
-                            self.manager.conf.polling.tenant_name_discovery and
-                            self._cache
-                        ):
+                        if self._name_discovery and self._cache:
 
                             # Try to resolve project UUIDs from cache first,
                             # and then keystone
@@ -282,22 +314,110 @@ class PollingTask(object):
                         exc_info=True)
 
     def _send_notification(self, samples):
-        self.manager.notifier.sample(
-            {},
-            'telemetry.polling',
-            {'samples': samples}
+        if self.manager.conf.polling.enable_notifications:
+            self.manager.notifier.sample(
+                {},
+                'telemetry.polling',
+                {'samples': samples}
+            )
+        if self.manager.conf.polling.enable_prometheus_exporter:
+            prom_exporter.collect_metrics(samples)
+
+
+class AgentHeartBeatManager(cotyledon.Service):
+    def __init__(self, worker_id, conf, namespaces=None, queue=None):
+        super(AgentHeartBeatManager, self).__init__(worker_id)
+        self.conf = conf
+
+        if conf.polling.heartbeat_socket_dir is None:
+            raise HeartBeatException("path to a directory containing "
+                                     "heart beat sockets is required", conf)
+
+        if type(namespaces) is not list:
+            if namespaces is None:
+                namespaces = ""
+            namespaces = [namespaces]
+
+        self._lock = threading.Lock()
+        self._queue = queue
+        self._status = dict()
+        self._sock_pth = os.path.join(
+            conf.polling.heartbeat_socket_dir,
+            f"ceilometer-{'-'.join(sorted(namespaces))}.socket"
         )
 
+        self._delete_socket()
+        self._sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
+        try:
+            self._sock.bind(self._sock_pth)
+            self._sock.listen(1)
+        except socket.error as err:
+            raise HeartBeatException("Failed to open socket file "
+                                     f"({self._sock_pth}): {err}", conf)
+
+        LOG.info("Starting heartbeat child service. Listening"
+                 f" on {self._sock_pth}")
+
+    def _delete_socket(self):
+        try:
+            os.remove(self._sock_pth)
+        except OSError:
+            pass
+
+    def terminate(self):
+        self._tpe.shutdown(wait=False, cancel_futures=True)
+        self._sock.close()
+        self._delete_socket()
+
+    def _update_status(self):
+        hb = self._queue.get()
+        with self._lock:
+            self._status[hb['pollster']] = hb['timestamp']
+        LOG.debug(f"Updated heartbeat for {hb['pollster']} "
+                  f"({hb['timestamp']})")
+
+    def _send_heartbeat(self):
+        s, addr = self._sock.accept()
+        LOG.debug("Heartbeat status report requested "
+                  f"at {self._sock_pth}")
+        with self._lock:
+            out = '\n'.join([f"{k} {v}"
+                             for k, v in self._status.items()])
+        s.sendall(out.encode('utf-8'))
+        s.close()
+        LOG.debug(f"Reported heartbeat status:\n{out}")
+
+    def run(self):
+        super(AgentHeartBeatManager, self).run()
+
+        LOG.debug("Started heartbeat child process.")
+
+        def _read_queue():
+            LOG.debug("Started heartbeat update thread")
+            while True:
+                self._update_status()
+
+        def _report_status():
+            LOG.debug("Started heartbeat reporting thread")
+            while True:
+                self._send_heartbeat()
+
+        with futures.ThreadPoolExecutor(max_workers=2) as executor:
+            self._tpe = executor
+            executor.submit(_read_queue)
+            executor.submit(_report_status)
+
 
 class AgentManager(cotyledon.Service):
 
-    def __init__(self, worker_id, conf, namespaces=None):
+    def __init__(self, worker_id, conf, namespaces=None, queue=None):
         namespaces = namespaces or ['compute', 'central']
         group_prefix = conf.polling.partitioning_group_prefix
 
         super(AgentManager, self).__init__(worker_id)
 
         self.conf = conf
+        self._queue = queue
 
         if type(namespaces) is not list:
             namespaces = [namespaces]
@@ -342,14 +462,35 @@ class AgentManager(cotyledon.Service):
         self.group_prefix = ('%s-%s' % (namespace_prefix, group_prefix)
                              if group_prefix else namespace_prefix)
 
-        self.notifier = oslo_messaging.Notifier(
-            messaging.get_transport(self.conf),
-            driver=self.conf.publisher_notifier.telemetry_driver,
-            publisher_id="ceilometer.polling")
+        if self.conf.polling.enable_notifications:
+            self.notifier = oslo_messaging.Notifier(
+                messaging.get_transport(self.conf),
+                driver=self.conf.publisher_notifier.telemetry_driver,
+                publisher_id="ceilometer.polling")
+
+        if self.conf.polling.enable_prometheus_exporter:
+            for addr in self.conf.polling.prometheus_listen_addresses:
+                address = netutils.parse_host_port(addr)
+                if address[0] is None or address[1] is None:
+                    LOG.warning('Ignoring invalid address: %s', addr)
+                prom_exporter.export(address[0], address[1])
 
         self._keystone = None
         self._keystone_last_exception = None
 
+    def heartbeat(self, name, timestamp):
+        """Send heartbeat data if the agent is configured to do so."""
+        if self._queue is not None:
+            try:
+                hb = {
+                    'timestamp': timestamp,
+                    'pollster': name
+                }
+                self._queue.put_nowait(hb)
+                LOG.debug(f"Polster heartbeat update: {name}")
+            except queue.Full:
+                LOG.warning(f"Heartbeat queue full. Update failed: {hb}")
+
     def create_dynamic_pollsters(self, namespaces):
         """Creates dynamic pollsters
 
