@@ -19,7 +19,7 @@ from oslo_log import log
 from oslo_utils import strutils
 import requests
 from requests import adapters
-from six.moves.urllib import parse as urlparse
+from urllib import parse as urlparse
 
 from ceilometer import publisher
 
@@ -159,7 +159,7 @@ class HttpPublisher(publisher.ConfigPublisherBase):
 
     def _individual_post(self, data):
         for d in data:
-            self._do_post(json.dumps(data))
+            self._do_post(json.dumps(d))
 
     def _batch_post(self, data):
         if not data:
