@@ -273,9 +273,9 @@ TEMPERATURE_DATA = {
 
 
 CURRENT_DATA = {
-    'Avg Power (0x2e)': {
+    'Current 1 (0x6b)': {
         'Status': 'ok',
-        'Sensor Reading': '130 (+/- 0) Watts',
+        'Sensor Reading': '0.800 (+/- 0) Amps',
         'Entity ID': '21.0 (Power Management)',
         'Assertions Enabled': '',
         'Event Message Control': 'Per-threshold',
@@ -284,10 +284,56 @@ CURRENT_DATA = {
         'Sensor Type (Analog)': 'Current',
         'Negative Hysteresis': 'Unspecified',
         'Maximum sensor range': 'Unspecified',
-        'Sensor ID': 'Avg Power (0x2e)',
+        'Sensor ID': 'Current 1 (0x6b)',
         'Assertion Events': '',
         'Minimum sensor range': '2550.000',
         'Settable Thresholds': 'No Thresholds'
+    },
+    'Pwr Consumption (0x76)': {
+        'Entity ID': '7.1 (System Board)',
+        'Sensor Type (Threshold)': 'Current (0x03)',
+        'Sensor Reading': '160 (+/- 0) Watts',
+        'Status': 'ok',
+        'Nominal Reading': '1034.000',
+        'Normal Maximum': '1056.000',
+        'Upper critical': '1914.000',
+        'Upper non-critical': '1738.000',
+        'Positive Hysteresis': 'Unspecified',
+        'Negative Hysteresis': 'Unspecified',
+        'Minimum sensor range': 'Unspecified',
+        'Maximum sensor range': '5588.000',
+        'Sensor ID': 'Pwr Consumption (0x76)',
+        'Event Message Control': 'Per-threshold',
+        'Readable Thresholds': 'unc ucr',
+        'Settable Thresholds': 'unc',
+        'Assertion Events': '',
+        'Assertions Enabled': 'unc+ ucr+',
+        'Deassertions Enabled': 'unc+ ucr+'
+    }
+}
+
+
+POWER_DATA = {
+    'Pwr Consumption (0x76)': {
+        'Entity ID': '7.1 (System Board)',
+        'Sensor Type (Threshold)': 'Current (0x03)',
+        'Sensor Reading': '154 (+/- 0) Watts',
+        'Status': 'ok',
+        'Nominal Reading': '1034.000',
+        'Normal Maximum': '1056.000',
+        'Upper critical': '1914.000',
+        'Upper non-critical': '1738.000',
+        'Positive Hysteresis': 'Unspecified',
+        'Negative Hysteresis': 'Unspecified',
+        'Minimum sensor range': 'Unspecified',
+        'Maximum sensor range': '5588.000',
+        'Sensor ID': 'Pwr Consumption (0x76)',
+        'Event Message Control': 'Per-threshold',
+        'Readable Thresholds': 'unc ucr',
+        'Settable Thresholds': 'unc',
+        'Assertion Events': '',
+        'Assertions Enabled': 'unc+ ucr+',
+        'Deassertions Enabled': 'unc+ ucr+'
     }
 }
 
@@ -649,29 +695,32 @@ VOLTAGE_DATA = {
 
 
 SENSOR_DATA = {
-    'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
+    'metadata': {'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
+                 'timestamp': '2015-06-1909:19:35.786893'},
     'publisher_id': 'f23188ca-c068-47ce-a3e5-0e27ffe234c6',
     'payload': {
         'instance_uuid': 'f11251ax-c568-25ca-4582-0x27add644c6',
-        'timestamp': '20140223134852',
+        'timestamp': '2017-07-07 15:54:12.169510',
         'node_uuid': 'f4982fd2-2f2b-4bb5-9aff-48aac801d1ad',
         'event_type': 'hardware.ipmi.metrics.update',
         'payload': {
             'Temperature': TEMPERATURE_DATA,
             'Current': CURRENT_DATA,
             'Fan': FAN_DATA,
-            'Voltage': VOLTAGE_DATA
+            'Voltage': VOLTAGE_DATA,
+            'Power': POWER_DATA
         }
     }
 }
 
 
 EMPTY_PAYLOAD = {
-    'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
+    'metadata': {'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
+                 'timestamp': '2015-06-1909:19:35.786893'},
     'publisher_id': 'f23188ca-c068-47ce-a3e5-0e27ffe234c6',
     'payload': {
         'instance_uuid': 'f11251ax-c568-25ca-4582-0x27add644c6',
-        'timestamp': '20140223134852',
+        'timestamp': '2017-07-07 15:54:12.169510',
         'node_uuid': 'f4982fd2-2f2b-4bb5-9aff-48aac801d1ad',
         'event_type': 'hardware.ipmi.metrics.update',
         'payload': {
@@ -681,11 +730,12 @@ EMPTY_PAYLOAD = {
 
 
 MISSING_SENSOR = {
-    'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
+    'metadata': {'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
+                 'timestamp': '2015-06-1909:19:35.786893'},
     'publisher_id': 'f23188ca-c068-47ce-a3e5-0e27ffe234c6',
     'payload': {
         'instance_uuid': 'f11251ax-c568-25ca-4582-0x27add644c6',
-        'timestamp': '20140223134852',
+        'timestamp': '2017-07-07 15:54:12.169510',
         'node_uuid': 'f4982fd2-2f2b-4bb5-9aff-48aac801d1ad',
         'event_type': 'hardware.ipmi.metrics.update',
         'payload': {
@@ -719,11 +769,12 @@ MISSING_SENSOR = {
 
 
 BAD_SENSOR = {
-    'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
+    'metadata': {'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
+                 'timestamp': '2015-06-1909:19:35.786893'},
     'publisher_id': 'f23188ca-c068-47ce-a3e5-0e27ffe234c6',
     'payload': {
         'instance_uuid': 'f11251ax-c568-25ca-4582-0x27add644c6',
-        'timestamp': '20140223134852',
+        'timestamp': '2017-07-07 15:54:12.169510',
         'node_uuid': 'f4982fd2-2f2b-4bb5-9aff-48aac801d1ad',
         'event_type': 'hardware.ipmi.metrics.update',
         'payload': {
@@ -758,11 +809,13 @@ BAD_SENSOR = {
 
 
 NO_SENSOR_ID = {
+    'metadata': {'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
+                 'timestamp': '2015-06-1909:19:35.786893'},
     'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
     'publisher_id': 'f23188ca-c068-47ce-a3e5-0e27ffe234c6',
     'payload': {
         'instance_uuid': 'f11251ax-c568-25ca-4582-0x27add644c6',
-        'timestamp': '20140223134852',
+        'timestamp': '2017-07-07 15:54:12.169510',
         'node_uuid': 'f4982fd2-2f2b-4bb5-9aff-48aac801d1ad',
         'event_type': 'hardware.ipmi.metrics.update',
         'payload': {
@@ -777,11 +830,12 @@ NO_SENSOR_ID = {
 
 
 NO_NODE_ID = {
-    'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
+    'metadata': {'message_id': 'f22188ca-c068-47ce-a3e5-0e27ffe234c6',
+                 'timestamp': '2015-06-1909:19:35.786893'},
     'publisher_id': 'f23188ca-c068-47ce-a3e5-0e27ffe234c6',
     'payload': {
         'instance_uuid': 'f11251ax-c568-25ca-4582-0x27add644c6',
-        'timestamp': '20140223134852',
+        'timestamp': '2017-07-07 15:54:12.169510',
         'event_type': 'hardware.ipmi.metrics.update',
         'payload': {
             'Temperature': {
