@@ -93,27 +93,8 @@ function _ceilometer_prepare_coordination {
     fi
 }
 
-# Install the python modules for inspecting nova virt instances
-function _ceilometer_prepare_virt_drivers {
-    # Only install virt drivers if we're running nova compute
-    if is_service_enabled n-cpu ; then
-        # NOTE(tkajinam): pythonN-libvirt is installed using distro
-        # packages in devstack
-
-        if [[ "$VIRT_DRIVER" = 'vsphere' ]]; then
-            pip_install_gr oslo.vmware
-        fi
-    fi
-}
-
-
 # Create ceilometer related accounts in Keystone
 function ceilometer_create_accounts {
-    # At this time, the /etc/openstack/clouds.yaml is available,
-    # we could leverage that by setting OS_CLOUD
-    OLD_OS_CLOUD=$OS_CLOUD
-    export OS_CLOUD='devstack-admin'
-
     create_service_user "ceilometer" "admin"
 
     if is_service_enabled swift; then
@@ -121,7 +102,7 @@ function ceilometer_create_accounts {
         get_or_add_user_project_role "ResellerAdmin" "ceilometer" $SERVICE_PROJECT_NAME
     fi
 
-    if ! [[ $DEVSTACK_PLUGINS =~ 'gnocchi' ]] && [[ "$CEILOMETER_BACKENDS" =~ "gnocchi" ]]; then
+    if [[ "$CEILOMETER_BACKENDS" =~ "gnocchi" ]]; then
         create_service_user "gnocchi"
         local gnocchi_service=$(get_or_create_service "gnocchi" \
             "metric" "OpenStack Metric Service")
@@ -131,7 +112,6 @@ function ceilometer_create_accounts {
             "$(gnocchi_service_url)" \
             "$(gnocchi_service_url)"
     fi
-    export OS_CLOUD=$OLD_OS_CLOUD
 }
 
 
@@ -161,11 +141,7 @@ function configure_gnocchi {
     iniset $GNOCCHI_CONF metricd metric_processing_delay "$GNOCCHI_METRICD_PROCESSING_DELAY"
 
     iniset $GNOCCHI_CONF api auth_mode keystone
-    configure_auth_token_middleware $GNOCCHI_CONF gnocchi $GNOCCHI_AUTH_CACHE_DIR
-
-    sudo mkdir -p $GNOCCHI_AUTH_CACHE_DIR
-    sudo chown $STACK_USER $GNOCCHI_AUTH_CACHE_DIR
-    rm -f $GNOCCHI_AUTH_CACHE_DIR/*
+    configure_keystone_authtoken_middleware $GNOCCHI_CONF gnocchi
 
     gnocchi-upgrade
 
@@ -222,7 +198,7 @@ function _ceilometer_configure_storage_backend {
             if [ "$CEILOMETER_BACKEND" = 'gnocchi' ] ; then
                 echo "          - gnocchi://?archive_policy=${GNOCCHI_ARCHIVE_POLICY}&filter_project=service" >> $CEILOMETER_CONF_DIR/event_pipeline.yaml
                 echo "          - gnocchi://?archive_policy=${GNOCCHI_ARCHIVE_POLICY}&filter_project=service" >> $CEILOMETER_CONF_DIR/pipeline.yaml
-                ! [[ $DEVSTACK_PLUGINS =~ 'gnocchi' ]] && configure_gnocchi
+                configure_gnocchi
             elif [ "$CEILOMETER_BACKEND" = 'sg-core' ] ; then
                 echo "          - tcp://127.0.0.1:4242" >> $CEILOMETER_CONF_DIR/event_pipeline.yaml
                 echo "          - tcp://127.0.0.1:4242" >> $CEILOMETER_CONF_DIR/pipeline.yaml
@@ -236,9 +212,6 @@ function _ceilometer_configure_storage_backend {
 
 # Configure Ceilometer
 function configure_ceilometer {
-
-    local conffile
-
     iniset_rpc_backend ceilometer $CEILOMETER_CONF
 
     iniset $CEILOMETER_CONF oslo_messaging_notifications topics "$CEILOMETER_NOTIFICATION_TOPICS"
@@ -283,19 +256,19 @@ function configure_ceilometer {
     iniset $CEILOMETER_CONF service_credentials region_name $REGION_NAME
     iniset $CEILOMETER_CONF service_credentials auth_url $KEYSTONE_SERVICE_URI
 
-    if [[ "$VIRT_DRIVER" = 'vsphere' ]]; then
-        iniset $CEILOMETER_CONF DEFAULT hypervisor_inspector vsphere
-        iniset $CEILOMETER_CONF vmware host_ip "$VMWAREAPI_IP"
-        iniset $CEILOMETER_CONF vmware host_username "$VMWAREAPI_USER"
-        iniset $CEILOMETER_CONF vmware host_password "$VMWAREAPI_PASSWORD"
-    fi
-
     _ceilometer_configure_storage_backend
 
     if is_service_enabled ceilometer-aipmi; then
         # Configure rootwrap for the ipmi agent
         configure_rootwrap ceilometer
     fi
+
+    if [[ "$VIRT_DRIVER" = 'libvirt' ]]; then
+        if ! getent group $LIBVIRT_GROUP >/dev/null; then
+            sudo groupadd $LIBVIRT_GROUP
+        fi
+        add_user_to_group $STACK_USER $LIBVIRT_GROUP
+    fi
 }
 
 # init_ceilometer() - Initialize etc.
@@ -314,23 +287,17 @@ function install_ceilometer {
         _ceilometer_prepare_coordination
     fi
 
-    ! [[ $DEVSTACK_PLUGINS =~ 'gnocchi' ]] && [[ "$CEILOMETER_BACKENDS" =~ 'gnocchi' ]] && install_gnocchi
-
-    if is_service_enabled ceilometer-acompute ; then
-        _ceilometer_prepare_virt_drivers
-    fi
-
     if [[ "$CEILOMETER_BACKENDS" =~ 'gnocchi' ]]; then
-        extra=gnocchi
+        install_gnocchi
     fi
-    setup_develop $CEILOMETER_DIR $extra
+    setup_develop $CEILOMETER_DIR
     sudo install -d -o $STACK_USER -m 755 $CEILOMETER_CONF_DIR
 }
 
 # start_ceilometer() - Start running processes, including screen
 function start_ceilometer {
 
-    if ! [[ $DEVSTACK_PLUGINS =~ 'gnocchi' ]] && [[ "$CEILOMETER_BACKENDS" =~ "gnocchi" ]] ; then
+    if [[ "$CEILOMETER_BACKENDS" =~ "gnocchi" ]] ; then
         run_process gnocchi-api "$CEILOMETER_BIN_DIR/uwsgi --ini $GNOCCHI_UWSGI_FILE" ""
         run_process gnocchi-metricd "$CEILOMETER_BIN_DIR/gnocchi-metricd --config-file $GNOCCHI_CONF"
         wait_for_service 30 "$(gnocchi_service_url)"
@@ -344,14 +311,7 @@ function start_ceilometer {
     # operational keystone if using gnocchi
     run_process ceilometer-anotification "$CEILOMETER_BIN_DIR/ceilometer-agent-notification --config-file $CEILOMETER_CONF"
 
-    # Start the compute agent late to allow time for the notification agent to
-    # fully wake up and connect to the message bus. See bug #1355809
-    if [[ "$VIRT_DRIVER" = 'libvirt' ]]; then
-        run_process ceilometer-acompute "$CEILOMETER_BIN_DIR/ceilometer-polling --polling-namespaces compute --config-file $CEILOMETER_CONF" $LIBVIRT_GROUP
-    fi
-    if [[ "$VIRT_DRIVER" = 'vsphere' ]]; then
-        run_process ceilometer-acompute "$CEILOMETER_BIN_DIR/ceilometer-polling --polling-namespaces compute --config-file $CEILOMETER_CONF"
-    fi
+    run_process ceilometer-acompute "$CEILOMETER_BIN_DIR/ceilometer-polling --polling-namespaces compute --config-file $CEILOMETER_CONF" $LIBVIRT_GROUP
 }
 
 # stop_ceilometer() - Stop running processes
